aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/protobuf/rewriter_config.proto
diff options
context:
space:
mode:
authorGravatar Gunhan Gulsoy <gunan@google.com>2018-03-01 22:25:41 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-03-01 22:29:38 -0800
commit1401b731cc2df2ca48117216b5f91c9f2070ae3c (patch)
tree7bbd2e3e109414f0827e1ee2208fb0c2ab89e132 /tensorflow/core/protobuf/rewriter_config.proto
parentbf1abe945330dffe3f93b81344185f629bef023f (diff)
Automated g4 rollback of changelist 187563544
PiperOrigin-RevId: 187582263
Diffstat (limited to 'tensorflow/core/protobuf/rewriter_config.proto')
-rw-r--r--tensorflow/core/protobuf/rewriter_config.proto16
1 files changed, 9 insertions, 7 deletions
diff --git a/tensorflow/core/protobuf/rewriter_config.proto b/tensorflow/core/protobuf/rewriter_config.proto
index 63303fa968..9ebf217811 100644
--- a/tensorflow/core/protobuf/rewriter_config.proto
+++ b/tensorflow/core/protobuf/rewriter_config.proto
@@ -78,14 +78,16 @@ message RewriterConfig {
// effect on manually requested memory optimization passes in the optimizers
// field.
MemOptType memory_optimization = 4;
// A regexp for node names which are valid outputs of recomputations. Inputs
// to nodes that match this regexp may be recomputed (subject either to manual
// annotation of those input nodes or to manual annotation and heuristics
- // depending on memory_optimization), but the nodes themselves will not be
- // recomputed. This is a prefix match, meaning it matches any node name that
- // contains a prefix that matches this regexp. Defaults to "gradients/" if
- // not provided, but can be changed if used within scopes.
- string memory_optimizer_target_node_name_regexp = 6;
+ // depending on memory_optimization), but the prefixed nodes themselves will
+ // not be recomputed. Typically this will be "gradients/", indicating that
+ // activations from the forward pass of a graph may be recomputed as inputs to
+ // gradients, but may be adjusted if gradients are inside a name scope or if
+ // inputs to non-gradients should be recomputed. Defaults to "gradients/" if
+ // empty or not set.
+ string memory_optimizer_target_node_name_prefix = 6;
// Configures AutoParallel optimization passes either through the
// meta-optimizer or when manually specified through the optimizers field.
@@ -78,14 +78,16 @@ message RewriterConfig {
// field.
MemOptType memory_optimization = 4;
- // A regexp for node names which are valid outputs of recomputations. Inputs
- // to nodes that match this regexp may be recomputed (subject either to manual
+ // The prefix for nodes which are valid outputs of recomputations. Inputs to
+ // nodes with this name prefix may be recomputed (subject either to manual
// annotation of those input nodes or to manual annotation and heuristics